pytilities.types — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »

# pytilities.types

Various types

Classes:

- NumericType: Represents any numeric type.
- NumberType: Represents any number type.
- SequenceType: Represents any ordered sequence.
- all types from the standard types package

Contents

- NumberType
- NumericType
- SequenceType
- _NumberTypeMeta
- _NumericTypeMeta
- _SequenceTypeMeta

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »